@@ -37,13 +37,16 @@ __all__ = (
     "TagTypeDef",
     "UserTypeDef",
     "CreateGroupResponseTypeDef",
+    "CreateOrganizationResponseTypeDef",
     "CreateResourceResponseTypeDef",
     "CreateUserResponseTypeDef",
+    "DeleteOrganizationResponseTypeDef",
     "DescribeGroupResponseTypeDef",
     "DescribeMailboxExportJobResponseTypeDef",
     "DescribeOrganizationResponseTypeDef",
     "DescribeResourceResponseTypeDef",
     "DescribeUserResponseTypeDef",
+    "DomainTypeDef",
     "GetAccessControlEffectResponseTypeDef",
     "GetDefaultRetentionPolicyResponseTypeDef",
     "GetMailboxDetailsResponseTypeDef",
@@ -154,7 +157,13 @@ MemberTypeDef = TypedDict(
 
 OrganizationSummaryTypeDef = TypedDict(
     "OrganizationSummaryTypeDef",
-    {"OrganizationId": str, "Alias": str, "ErrorMessage": str, "State": str},
+    {
+        "OrganizationId": str,
+        "Alias": str,
+        "DefaultMailDomain": str,
+        "ErrorMessage": str,
+        "State": str,
+    },
     total=False,
 )
 
@@ -200,12 +209,20 @@ UserTypeDef = TypedDict(
 
 CreateGroupResponseTypeDef = TypedDict("CreateGroupResponseTypeDef", {"GroupId": str}, total=False)
 
+CreateOrganizationResponseTypeDef = TypedDict(
+    "CreateOrganizationResponseTypeDef", {"OrganizationId": str}, total=False
+)
+
 CreateResourceResponseTypeDef = TypedDict(
     "CreateResourceResponseTypeDef", {"ResourceId": str}, total=False
 )
 
 CreateUserResponseTypeDef = TypedDict("CreateUserResponseTypeDef", {"UserId": str}, total=False)
 
+DeleteOrganizationResponseTypeDef = TypedDict(
+    "DeleteOrganizationResponseTypeDef", {"OrganizationId": str, "State": str}, total=False
+)
+
 DescribeGroupResponseTypeDef = TypedDict(
     "DescribeGroupResponseTypeDef",
     {
@@ -284,6 +301,8 @@ DescribeUserResponseTypeDef = TypedDict(
     total=False,
 )
 
+DomainTypeDef = TypedDict("DomainTypeDef", {"DomainName": str, "HostedZoneId": str}, total=False)
+
 GetAccessControlEffectResponseTypeDef = TypedDict(
     "GetAccessControlEffectResponseTypeDef",
     {"Effect": Literal["ALLOW", "DENY"], "MatchedRules": List[str]},
